@@ -79,14 +79,14 @@ double interpolate(double y, double *stuetz, int nstuetz, int origin,
 double constant(double *x, double *p, int effectivedim){
   return 1.0;
 }
-double TBM2constant(double *x, double *p, int effectivedim) 
+double TBM2constant(double *x, double *p) 
 {
   return 1.0;
 }
-double TBM3constant(double *x, double *p, int effectivedim){
+double TBM3constant(double *x, double *p){
    return 1.0;
 }
-double Dconstant(double *x, double *p, int effectivedim){
+double Dconstant(double *x, double *p){
   return 0.0;
 }
 void rangeconstant(int dim, int *index, double* range){ 
@@ -106,23 +106,26 @@ double exponential(double *x, double *p, int effectivedim){
   return exp(-fabs( *x));
 }
 double Scaleexponential(double *p, int scaling){ return MINUSINVLOG005; } 
-double TBM2exponential(double *x, double *p, int effectivedim) 
+double TBM2exponential(double *x, double *p) 
 {
   double y;
   if (*x==0.0) {return 1.0;}
   y = fabs(*x);
   return 1.0 - PIHALF * y * I0mL0(y);
 }
-double TBM3exponential(double *x, double *p, int effectivedim){
+double TBM3exponential(double *x, double *p){
    register double y;
    y = fabs( *x);
    return (1.0-y)*exp(-y);
 }
-double Dexponential(double *x, double *p, int effectivedim){
+double Dexponential(double *x, double *p){
 //  printf("\n ******* dexp %f %f\n", *x, - exp(-fabs( *x)));
   return - exp(-fabs( *x));
 }
-double spectralexponential(double *p ) { /* see Yaglom ! */
+double DDexponential(double *x, double *p){
+  return exp(-fabs( *x));
+}
+double spectralexponential(double *p) { /* see Yaglom ! */
   double register y;
   y = 1.0 - UNIFORM_RANDOM;
   return sqrt(1.0 / (y * y) - 1.0);
@@ -244,14 +247,14 @@ int checkqexponential(double *param, int timespacedim, SimulationType method){
   }
   return NOERROR;  
 }
-double TBM3qexponential(double *x, double *p, int effectivedim){
+double TBM3qexponential(double *x, double *p){
    register double y;
    y = exp(-fabs( *x));
    return (y * (2.0  - p[KAPPA] * y) + 
 	   fabs( *x) * y * (y * (p[KAPPA] * y - 1.0) * 2.0)) / 
      (2.0 - p[KAPPA]);
 }
-double Dqexponential(double *x, double *p, int effectivedim) {
+double Dqexponential(double *x, double *p) {
   register double y;
   y = exp(-fabs( *x));
   return y * (p[KAPPA] * y - 1.0) * 2.0 / (2.0 - p[KAPPA]);
@@ -277,12 +280,12 @@ double Scaledampedcosine(double *p,int scaling){
   if (scaling==NATSCALE_EXACT) return 0.0;
   return MINUSINVLOG005; 
 } 
-double TBM3dampedcosine(double *x, double *p, int effectivedim){
+double TBM3dampedcosine(double *x, double *p){
   register double y;
   y = fabs( *x);
   return exp(-p[KAPPA]*y) * ((1.0 - p[KAPPA] * y) * cos(y) - y * sin(y));
 }
-double Ddampedcosine(double *x, double *p, int effectivedim){
+double Ddampedcosine(double *x, double *p){
   register double y;
   y = fabs( *x);
   return - exp(-p[KAPPA]*y) * (p[KAPPA] * cos(y) + sin(y));
@@ -342,7 +345,7 @@ double circular(double *x, double *p, int effectivedim)
 double Scalecircular(double *p,int scaling) {return 1.138509531721630274603;}
 // spectral measure, see Lantue !! 
 
-double Dcircular(double *x, double *p, int dim){
+double Dcircular(double *x, double *p){
   register double y;
   if ((y=*x * *x) >= 1.0) {return 0.0;} 
   return -4 * INVPI * sqrt(1 - y);
@@ -372,24 +375,18 @@ double spherical(double *x, double *p, int effectivedim){
   return (1.0+y*0.5*(y*y-3.0));
 }
 double Scalespherical(double *p,int scaling){ return 1.23243208931941;}
-double TBM2spherical(double *x, double *p, int effectivedim){
+double TBM2spherical(double *x, double *p){
   register double y, y2;
   y=fabs( *x); y2=y*y;
-  if (effectivedim <= 2) {
-    if (y>1.0)
-      {return (1.0- 0.75 * y * ((2.0 - y2) * asin(1.0/y) + 
-				sqrt(y2 -1.0)));} 
-    return (1.0 - 0.375 * PI * y * (2.0 - y2));
-  } else {
-    assert(false);
-  }
+  if (y>1.0) return (1.0- 0.75 * y * ((2.0 - y2) * asin(1.0/y) + sqrt(y2 -1.0)));
+  return (1.0 - 0.375 * PI * y * (2.0 - y2));
 }
-double TBM3spherical(double *x, double *p, int effectivedim){
+double TBM3spherical(double *x, double *p){
   register double y;
   if ((y=fabs( *x))>1.0) {return 0.0;} 
   return (1.0 + (-3.0 + 2.0 * y * y) * y);
 }
-double Dspherical(double *x, double *p, int effectivedim){
+double Dspherical(double *x, double *p){
   register double y;
   if ((y=fabs( *x))>1.0) {return 0.0;} 
   return  1.5 * (y * y - 1.0);
@@ -420,7 +417,7 @@ double power(double *x, double *p, int effectivedim){
 double Scalepower(double *p,int scaling){ 
   return 1.0 / (1.0 - pow(0.05,1/p[KAPPA]));
 }
-double TBM2power(double *x, double *p, int effectivedim){
+double TBM2power(double *x, double *p){
   // only kappa=2 up to now !
   register double y;
   y=fabs( *x);
@@ -428,13 +425,13 @@ double TBM2power(double *x, double *p, int effectivedim){
     {return (1.0 - 2.0 * y *(asin(1.0/y) - y + sqrt(y*y-1.0) ));} 
   return (1.0 - y * (PI - 2.0 * y));
 }
-double TBM3power(double *x, double *p, int effectivedim){
+double TBM3power(double *x, double *p){
   register double y;
   if ((y=fabs( *x))>1.0) {return 0.0;} 
   return  (1.0 - y - y * p[KAPPA]) *
     pow(1.0 - y, p[KAPPA]-1.0);
 }
-double Dpower(double *x, double *p, int effectivedim){
+double Dpower(double *x, double *p){
   register double y;
   if ((y=fabs( *x))>1.0) {return 0.0;} 
   return  -  p[KAPPA] * pow(1.0 - y, p[KAPPA]-1.0);
@@ -491,12 +488,12 @@ double stable(double *x,double *p, int effectivedim){
   return  (exp(-pow(fabs( *x), p[KAPPA])));
 }
 double Scalestable(double *p,int scaling){return pow(MINUSINVLOG005,1/p[KAPPA]);}
-double TBM3stable(double *x, double *p, int effectivedim){
+double TBM3stable(double *x, double *p){
   register double y;
   y = pow(fabs( *x),p[KAPPA]);
   return exp(-y) * (1 - p[KAPPA] * y);
 }
-double Dstable(double *x, double *p, int effectivedim){
+double Dstable(double *x, double *p){
   register double y, z;
   if ( (z = fabs( *x)) == 0.0) 
     return ((p[KAPPA] > 1.0) ? 0.0 : (p[KAPPA] < 1.0) ? INFTY : 1.0);
@@ -504,7 +501,7 @@ double Dstable(double *x, double *p, int effectivedim){
   return -p[KAPPA] * y * exp(-y * z);
 }
 /* stable: second derivative at t=1 */
-double DDstable(double *x, double*p, int effectivedim) 
+double DDstable(double *x, double*p) 
 {
   double y, xkappa, z;
   if ( (z = fabs( *x)) == 0.0) return ((p[KAPPA] != 1.0) ? INFTY : 1.0);
@@ -580,13 +577,13 @@ double ScaleWhittleMatern(double *p,int scaling){
 		     1.5, 5);
 }
 
-double TBM2WhittleMatern(double *x, double *p, int effectivedim) 
+double TBM2WhittleMatern(double *x, double *p) 
 {
-  if (p[KAPPA]==0.5) return TBM2exponential(x, p, effectivedim);
+  if (p[KAPPA]==0.5) return TBM2exponential(x, p);
   assert(false);
 }
 
-double TBM3WhittleMatern(double *x, double *p, int effectivedim)
+double TBM3WhittleMatern(double *x, double *p)
 // check calling functions, like hyperbolic and gneiting if any changings !!
 { 
   static double kappa=RF_INF;
@@ -605,7 +602,7 @@ double TBM3WhittleMatern(double *x, double *p, int effectivedim)
 		 log(bessel_k(y, kappa - 1.0, 2.0)) - y)));
 }  
 
-double DWhittleMatern(double *x, double *p, int effectivedim)
+double DWhittleMatern(double *x, double *p)
 // check calling functions, like hyperbolic and gneiting if any changings !!
 { 
   static double kappa=RF_INF;
@@ -622,7 +619,7 @@ double DWhittleMatern(double *x, double *p, int effectivedim)
 		    log(bessel_k(y, kappa - 1.0, 2.0)) - y);
 }
 
-double DDWhittleMatern(double *x, double *p, int effectivedim)
+double DDWhittleMatern(double *x, double *p)
 // check calling functions, like hyperbolic and gneiting if any changings !!
 { 
   static double kappa=RF_INF;
@@ -731,7 +728,7 @@ double hyperbolic(double *x, double*p, int effectivedim){
   return  
     exp(logconst + lambda * log(y)+log(bessel_k(kappay,lambda,2.0))-kappay);
 }
-double TBM3hyperbolic(double *x, double*p, int effectivedim)
+double TBM3hyperbolic(double *x, double*p)
 { 
   static double kappa = RF_INF;
   static double lambda= RF_INF;
@@ -744,7 +741,7 @@ double TBM3hyperbolic(double *x, double*p, int effectivedim)
   if ( *x==0.0) {return 1.0;}
   if (p[KAPPAIII]==0) { // whittle matern
     y = *x * p[KAPPAI];
-    return TBM3WhittleMatern(&y, p, effectivedim);
+    return TBM3WhittleMatern(&y, p);
   } 
   if (p[KAPPAI]==0) { //cauchy
     register double y,ha;
@@ -774,7 +771,7 @@ double TBM3hyperbolic(double *x, double*p, int effectivedim)
 		      +log(bessel_k(kappa_s,lambda-1.0,2.0))-kappa_s)
       );
 }
-double Dhyperbolic(double *x, double*p, int effectivedim)
+double Dhyperbolic(double *x, double*p)
 { 
   static double kappa = RF_INF;
   static double lambda= RF_INF;
@@ -787,7 +784,7 @@ double Dhyperbolic(double *x, double*p, int effectivedim)
   if ( *x==0.0) {return 1.0;}
   if (p[KAPPAIII]==0) { // whittle matern
     y = *x * p[KAPPAI];
-    return DWhittleMatern(&y, p, effectivedim);
+    return DWhittleMatern(&y, p);
   } 
   if (p[KAPPAI]==0) { //cauchy
     register double y,ha;
@@ -844,9 +841,8 @@ int checkhyperbolic(double *param, int timespacedim, SimulationType method){
 void rangehyperbolic(int dim, int *index, double* range){
   //  2 x length(param) x {theor, pract } 
   double r[12] = {0, RF_INF, 0.000001, 10.0,
-		RF_NEGINF, RF_INF, -20.0, 20.0,
-                0, RF_INF, 0.000001, 10.0
-                };
+		  RF_NEGINF, RF_INF, -20.0, 20.0,
+		  0, RF_INF, 0.000001, 10.0};
   *index = -1; 
   memcpy(range, r, sizeof(double) * 12);
 }
@@ -867,14 +863,14 @@ double Gneiting(double *x, double *p, int effectivedim){
   return ((1.0+y * ( 8.0 + y * (25.0 + 32.0 *y)))*oneMy8);
 }
 double ScaleGneiting(double *p,int scaling) {return 0.5854160193;}
-double TBM3Gneiting(double *x, double *p, int effectivedim){ 
+double TBM3Gneiting(double *x, double *p){ 
   register double y,oneMy7;
   if ((y=fabs( *x * NumericalScale))>1.0) {return 0.0;}  
   oneMy7 = 1.0-y; oneMy7*=oneMy7; oneMy7 *= oneMy7 * oneMy7 * (1.0-y);
   return 
     (1.0 + y * (7.0  -  y * (5.0 + y * (147.0 + 384.0 * y))))* oneMy7;
 }
-double DGneiting(double *x, double *p, int effectivedim){ 
+double DGneiting(double *x, double *p){ 
   register double y,oneMy7;
   if ((y=fabs( *x * NumericalScale))>1.0) {return 0.0;}  
   oneMy7 = 1.0-y; oneMy7*=oneMy7; oneMy7 *= oneMy7 * oneMy7 * (1.0-y);
@@ -917,7 +913,7 @@ double genGneiting(double *x, double *p, int effectivedim)
   default : assert(false);  
   }
 }
-double TBM3genGneiting(double *x, double *p, int effectivedim)
+double TBM3genGneiting(double *x, double *p)
 {
   register double y, s;
   if ((y=fabs( *x))>1.0) {return 0.0;} 
@@ -942,7 +938,7 @@ double TBM3genGneiting(double *x, double *p, int effectivedim)
   default : assert(false);   
   }
 }
-double DgenGneiting(double *x, double *p, int effectivedim)
+double DgenGneiting(double *x, double *p)
 {
   register double y, s;
   if ((y=fabs( *x))>1.0) {return 0.0;} 
@@ -1018,12 +1014,12 @@ double Gauss(double *x, double*p, int effectivedim) {
   return  exp(-  *x * *x);
 }
 double ScaleGauss(double *p,int scaling) {return SQRTINVLOG005;}
-double TBM3Gauss(double *x, double*p, int effectivedim) {
+double TBM3Gauss(double *x, double*p) {
   register double y;
   y =   *x *  *x; 
   return  (1-2.0*y)*exp(-y);
 }
-double DGauss(double *x, double*p, int effectivedim) {
+double DGauss(double *x, double*p) {
   register double y;
   y =   fabs( *x); 
   return  -  2.0 * y * exp(- y * y);
@@ -1060,7 +1056,7 @@ double ScaleCauchy(double *p,int scaling) {
   default: assert(false);
   }
 }
-double TBM2Cauchy(double *x, double *p, int effectivedim){
+double TBM2Cauchy(double *x, double *p){
   register double y2, lpy2;
   y2 = *x * *x; 
   lpy2=1.0+y2;
@@ -1072,17 +1068,17 @@ double TBM2Cauchy(double *x, double *p, int effectivedim){
   default : assert(false);
   }
 }
-double TBM3Cauchy(double *x, double *p, int effectivedim){
+double TBM3Cauchy(double *x, double *p){
   register double ha;
   ha= *x *  *x;
   return (1.0+ (1.0-2.0*p[KAPPA])*ha) * pow(1.0+ha,-p[KAPPA]-1.0);
 }
-double DCauchy(double *x, double *p, int effectivedim){
+double DCauchy(double *x, double *p){
   register double y;
   y = fabs( *x);
   return (-2.0 * p[KAPPA] * y) * pow(1.0 + y * y, -p[KAPPA] - 1.0);
 }
-double DDCauchy(double *x, double *p, int effectivedim){
+double DDCauchy(double *x, double *p){
   register double ha;
   ha = *x * *x;
   return 2.0 * p[KAPPA] * ((2.0 * p[KAPPA] + 1.0) * ha - 1.0) * 
@@ -1134,20 +1130,20 @@ double ScalegeneralisedCauchy(double *p,int scaling) {
   default: assert(false);
   }
 }
-double TBM3generalisedCauchy(double *x, double *p, int effectivedim){
+double TBM3generalisedCauchy(double *x, double *p){
   register double ha;
   ha=pow(fabs( *x), p[KAPPAI]);
   return 
     (1.0+ (1.0-p[KAPPAII])*ha) * pow(1.0 + ha, -p[KAPPAII] / p[KAPPAI] - 1.0);
 }
-double DgeneralisedCauchy(double *x, double *p, int effectivedim){
+double DgeneralisedCauchy(double *x, double *p){
   register double ha,y;
   if ((y = fabs(*x))==0.0) 
     return ((p[KAPPAI]>1.0) ? 0.0 : (p[KAPPAI]<1.0) ? -INFTY : -p[KAPPAII]); 
   ha=pow(y, p[KAPPAI] - 1.0);
   return  -  p[KAPPAII] * ha * pow(1.0 + ha * y,-p[KAPPAII] / p[KAPPAI] - 1.0);
 }
-double DDgeneralisedCauchy(double *x, double *p, int effectivedim){
+double DDgeneralisedCauchy(double *x, double *p){
   register double ha,y;
   if ((y = fabs(*x))==0.0) 
     return ((p[KAPPAI]==2.0) ? p[KAPPAII] * (p[KAPPAII] + 1.0) : INFTY); 
@@ -1201,7 +1197,7 @@ double Cauchytbm(double *x, double *p, int effectivedim){
   return (1.0 + (1.0 - p[KAPPAII] / p[KAPPAIII]) * ha) * 
       pow(1.0 + ha, -p[KAPPAII] / p[KAPPAI] - 1.0);
 }
-double TBM3Cauchytbm(double *x, double *p, int effectivedim){
+double TBM3Cauchytbm(double *x, double *p){
   register double bg,ha;
   ha=pow(fabs( *x),p[KAPPAI]);
   bg=p[KAPPAII]/p[KAPPAIII];
@@ -1209,7 +1205,7 @@ double TBM3Cauchytbm(double *x, double *p, int effectivedim){
     (1 + ha * (1-bg*(1+p[KAPPAI])+(1-p[KAPPAII]) * (1+(1-bg)*ha)))*
     pow(1+ha,-p[KAPPAII]/p[KAPPAI]-2.0);
 }
-double DCauchytbm(double *x, double *p, int effectivedim){
+double DCauchytbm(double *x, double *p){
   register double y,ha;
   if ((y = fabs(*x)) == 0.0) return 0.0; // WRONG VALUE, but multiplied 
   //                                        zero anyway
@@ -1343,14 +1339,14 @@ double cubic(double *x, double *p, int effectivedim)
   y2 = y * y;
   return  (1.0 + (((0.75 * y2 - 3.5) * y2 + 8.75) * y - 7) * y2);
 }
-double TBM3cubic(double *x, double *p, int effectivedim)
+double TBM3cubic(double *x, double *p)
 { ///
   double y, y2;
   if ((y=fabs(*x)) >= 1.0) {return 0.0;}
   y2 = y * y;
   return (1.0 + y2 * (-21.0 + y * (35.0 + y2 * (-21.0 + 6.0 * y2))));
 }
-double Dcubic(double *x, double *p, int effectivedim) 
+double Dcubic(double *x, double *p) 
 { ///
   double y,y2;
   if ((y=fabs(*x)) >= 1.0) {return 0.0;}
@@ -1387,7 +1383,7 @@ double penta(double *x, double *p, int effectivedim)
 				    y2 * (-5.5 + 
 					  y2 * 0.833333333333333))))));
 }
-double TBM3penta(double *x, double *p, int effectivedim)
+double TBM3penta(double *x, double *p)
 { ///
   double y,y2;
   if ((y=fabs( *x))>=1.0) { return 0.0; }
@@ -1400,7 +1396,7 @@ double TBM3penta(double *x, double *p, int effectivedim)
 					+ y2 * (-55.0 
 						+ 10.0 * y2))))));
 }
-double Dpenta(double *x, double *p, int effectivedim)
+double Dpenta(double *x, double *p)
 { ///
   double y,y2;
   if ((y=fabs( *x))>=1.0) { return 0.0; }
@@ -1438,7 +1434,7 @@ int checkpenta(double *param, int timespacedim, SimulationType method){
 double spacetime3(double *x,double *p, int effectivedim){
   // turning bands modified spacetime1 covariance function
   assert(effectivedim==2);
-  return spacetime1(x,p,effectivedim) + fabs(x[0]) * Dspacetime1(x,p,effectivedim);
+  return spacetime1(x,p, effectivedim) + fabs(x[0]) * Dspacetime1(x,p);
 }
 
 
@@ -1472,33 +1468,30 @@ double spacetime1(double *x, double *p, int effectivedim){
   }
   return pow(invsqrtpsi, p[KAPPAVI]) * z;
 }
-double TBM2spacetime1(double *x, double *p, int effectivedim){
+double TBM2spacetime1(double *x, double *p){
   double y, z, invsqrtpsi;
-  assert(effectivedim==2);
   invsqrtpsi = InvSqrtPsi(x[1],  p[KAPPAIII], p[KAPPAIV], (int)p[KAPPAV]);
   y = x[0] * invsqrtpsi; 
   switch((int) p[KAPPAII]) {
   case 1 : assert(false); break;
-  case 2 : z = TBM2WhittleMatern(&y, p, 1); break;
-  case 3 : z = TBM2Cauchy(&y, p, 1); break;
+  case 2 : z = TBM2WhittleMatern(&y, p); break;
+  case 3 : z = TBM2Cauchy(&y, p); break;
   default: assert(false);
   }
   return pow(invsqrtpsi, p[KAPPAVI]) * z;
 }
-double TBM3spacetime1(double *x, double *p, int effectivedim){
+double TBM3spacetime1(double *x, double *p){
   assert(false); // should never happen
-  return spacetime1(x, p, effectivedim) +
-    Dspacetime1(x, p, effectivedim) * fabs(x[0]);
+  return spacetime1(x, p, 2) + Dspacetime1(x, p) * fabs(x[0]);
 }
-double Dspacetime1(double *x, double *p, int effectivedim){
+double Dspacetime1(double *x, double *p){
   double y, z, invsqrtpsi;
-  assert(effectivedim==2);
   invsqrtpsi = InvSqrtPsi(x[1],  p[KAPPAIII], p[KAPPAIV], (int)p[KAPPAV]);
   y = x[0] * invsqrtpsi; 
   switch((int) p[KAPPAII]) {
-  case 1 : z = Dstable(&y, p, 1); break;
-  case 2 : z = DWhittleMatern(&y, p, 1); break;
-  case 3 : z = DCauchy(&y, p, 1); break;
+  case 1 : z = Dstable(&y, p); break;
+  case 2 : z = DWhittleMatern(&y, p); break;
+  case 3 : z = DCauchy(&y, p); break;
   default: assert(false);
   }
   return pow(invsqrtpsi, p[KAPPAVI] + 1.0) * z;
@@ -1542,8 +1535,8 @@ int checkspacetime1(double *param, int timespacedim, SimulationType method) {
     sprintf(ERRORSTRING_WRONG,"%f",param[KAPPAIII]);
     return ERRORCOVFAILED;
   }
-  if ((param[KAPPAIV]<=0) || (param[KAPPAIV]>1)) {
-    strcpy(ERRORSTRING_OK,"0<kappa4<=1");
+  if ((param[KAPPAIV]<=0) || (param[KAPPAIV]>=1)) {
+    strcpy(ERRORSTRING_OK,"0<kappa4<1");
     sprintf(ERRORSTRING_WRONG,"%f",param[KAPPAIV]);
     return ERRORCOVFAILED;
   } 
@@ -1611,7 +1604,6 @@ void infospacetime1(double *p, int *maxdim, int *CEbadlybehaved) {
 /* Tilmann Gneiting's space time models, part II*/
 double spacetime2(double *x,double *p, int effectivedim){
   double y, z, invsqrtpsi;
-  assert(effectivedim==2);
   invsqrtpsi = InvSqrtPsi(x[1],  p[KAPPAIV], p[KAPPAV], (int)p[KAPPAVI]);
   y = x[0] * invsqrtpsi; 
   switch((int) p[KAPPAIII]) {
@@ -1620,18 +1612,16 @@ double spacetime2(double *x,double *p, int effectivedim){
   }
   return pow(invsqrtpsi, p[KAPPAVII]) * z;
 }
-double TBM3spacetime2(double *x, double *p, int effectivedim){
+double TBM3spacetime2(double *x, double *p){
   assert(false); // should never happen
-  return spacetime2(x, p, effectivedim) +
-    Dspacetime2(x, p, effectivedim) * fabs(x[0]);
+  return spacetime2(x, p, 2) + Dspacetime2(x, p) * fabs(x[0]);
 }
-double Dspacetime2(double *x, double *p, int effectivedim){
+double Dspacetime2(double *x, double *p){
   double y, z, invsqrtpsi;
-  assert(effectivedim==2);
   invsqrtpsi = InvSqrtPsi(x[1],  p[KAPPAIV], p[KAPPAV], (int)p[KAPPAVI]);
   y = x[0] * invsqrtpsi; 
   switch((int) p[KAPPAIII]) {
-  case 1 : z = DgeneralisedCauchy(&y, p, 1); break;
+  case 1 : z = DgeneralisedCauchy(&y, p); break;
   default: assert(false);
   }
   return pow(invsqrtpsi, p[KAPPAV] + 1.0) * z;
@@ -1734,12 +1724,12 @@ double fractalBrownian(double*x, double *p, int effectivdim) {
 }
 //begin
 /* fractalBrownian: first derivative at t=1 */
-double DfractalBrownian(double *x, double*p, int effectivedim) 
+double DfractalBrownian(double *x, double*p) 
 {
     return -p[KAPPA] * pow(fabs(*x), p[KAPPA] - 1.0);
 }
 /* fractalBrownian: second derivative at t=1 */
-double DDfractalBrownian(double *x, double*p, int effectivedim)  
+double DDfractalBrownian(double *x, double*p)  
 {
     return -p[KAPPA] * (p[KAPPA]-1.0) * pow(fabs(*x), p[KAPPA] - 2.0);
 }
@@ -1822,7 +1812,7 @@ double Scalelgd1(double *p,int scaling) {
     return exp( log(0.95 * (p[KAPPAI] + p[KAPPAII]) / p[KAPPAII]) / p[KAPPAI]); 
   else return exp(log(0.05 * (p[KAPPAI] + p[KAPPAII]) / p[KAPPAI])/p[KAPPAII]);
 }
-double Dlgd1(double *x, double *p, int dim){
+double Dlgd1(double *x, double *p){
   double y, pp;
   if ( (y=fabs(*x)) == 0) return 0; // falscher Wert, aber sonst gibt NAN-Fehler
   pp = ( (y < 1) ? p[KAPPAI] : -p[KAPPAII] ) - 1.0;
