@@ -1,9 +1,12 @@
 
 library(RandomFields,
-        lib=if(TRUE && file.exists("/home/schlather/TMP/RandomFields")) "~/TMP")
+        lib=if (TRUE && file.exists("~/TMP/RandomFields") &&
+          file.exists("/home/schlather/TMP/RandomFields")) "~/TMP")
 
-.path <- "/home/schlather/R/RF/RandomFields/R/"
-if (EXTENDED.TESTING <- file.exists(paste(.path, "rf.R", sep=""))) {
+.path <- "~/R/RF/RandomFields/R/"
+.path2 <- "/home/schlather/R/RF/RandomFields/R/"
+if (EXTENDED.TESTING <- file.exists(paste(.path, "rf.R", sep="")) &&
+    file.exists(paste(.path2, "rf.R", sep=""))) {
   EXTENDED.TESTING <- FALSE
   Source <- function(x) {
     cat(x, "...\n")
